sfs.fd.wfs
==========

.. automodule:: sfs.fd.wfs

   
   
   .. rubric:: Functions

   .. autosummary::
   
      focused_25d
      focused_2d
      focused_3d
      line_2d
      plane_25d
      plane_2d
      plane_3d
      plane_3d_delay
      point_25d
      point_25d_legacy
      point_2d
      point_3d
      preeq_25d
      soundfigure_3d
   
   

   
   
   

   
   
   